Checks class

Dependencies for the check command

Constructors

Checks({required GgLog ggLog, Analyze? analyze, Format? format, Tests? tests, Pana? pana, IsPushed? isPushed, IsCommitted? isCommitted, IsVersioned? isVersioned, IsPublished? isPublished, IsUpgraded? isUpgraded})
Constructor

Properties

all Iterable<DirCommand<void>>
Returns a list of all commands
no setter
analyze Analyze
The analyze command
final
format Format
The format command
final
ggLog → GgLog
The log function
final
hashCode int
The hash code for this object.
no setterinherited
isCommitted → IsCommitted
The isCommitted command
final
isPublished → IsPublished
The isPublished command
final
isPushed → IsPushed
The isPushed command
final
isUpgraded → IsUpgraded
The isUpgraded command
final
isVersioned → IsVersioned
The isVersioned command
final
pana Pana
The pana command
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tests → Tests
The coverage command
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited