gg library
Classes
- Gg
- The parent command for Gg operations.
- ProjectDetector
- Detects whether the current directory belongs to a gg workspace or a single Dart/TypeScript project.
Enums
- ProjectMode
-
The mode of the project that
ggis invoked in.
Constants
- Top-level subcommand names that are shared between gg_multi and gg_one and are dispatched dynamically based on the detected project mode.
Functions
-
rewriteArgsForProjectMode(
List< String> args, ProjectMode detectMode()) → List<String> -
Rewrites
argsby insertingoneormultibefore the first non-flag argument when it is a sharedTopLevelCommands entry. Throws a StateError when the mode is ProjectMode.unknown.